@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/lr_parser.h,v 1.7 2006/01/09 16:30:20 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/lr_parser.h,v 1.8 2006/05/10 14:12:30 richb Exp $
  *
  *  Copyright (C) 2004-2006 Sami Pietila
  *
@@ -43,6 +43,6 @@ int ceerror(char *s);
 int lr_parse(char *expression, int result[MP_SIZE]);
 int lr_udf_parse(char *expression);
 
-void reset_ce_tokeniser();
+void reset_lr_tokeniser();
 
 #endif /*LR_PARSER_H*/
